#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InXM v8'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 355
ACMCVD = "".join(chr(c) for c in [67, 70, 71, 50, 49])
ACQFFT = "".join(chr(c) for c in [82, 104, 67, 111, 109, 109, 69, 114, 114])
AFIKJP = "".join(chr(c) for c in [75, 52, 48, 48])
AHEOCT = 294
AIIDNI = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
AJVDQL = "".join(chr(c) for c in [70, 117, 115, 101, 49, 69, 114, 114])
AKQXPI = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 80, 104, 97, 115, 101, 83, 105, 103, 110]
)
AKSTSE = 455
AMJMAO = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
AOAWBS = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
AONPYY = 359
ASSAKQ = "".join(chr(c) for c in [75, 54, 48, 48, 85, 112, 108, 111, 97, 100])
ATDZXN = "".join(chr(c) for c in [67, 70, 71, 48])
AWBSIR = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
AZMKQT = 474
BDFSRO = 256
BDJQRJ = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
BEKBDF = "".join(chr(c) for c in [76, 73])
BHZVOA = 466
BIAMJM = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
BJEUTO = "".join(chr(c) for c in [54, 52, 75])
BLKXSJ = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121])
BMJVHF = 263
BQFYLJ = "".join(chr(c) for c in [67, 80, 79, 84])
BQNRXC = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 118])
BQSNQL = 271
BSIRYX = "".join(chr(c) for c in [67, 108, 101, 97, 110])
BSKSOK = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
BSSUHB = "".join(chr(c) for c in [82, 104, 83, 87, 84, 114, 105, 97, 99, 79, 72])
BVWVUB = "".join(
    chr(c)
    for c in [82, 104, 72, 101, 97, 116, 101, 114, 68, 105, 115, 97, 98, 108, 101, 100]
)
BWJYKL = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
BXIBHZ = "".join(chr(c) for c in [67, 70, 71, 49, 55])
BXTIAC = 259
BXYBQS = 364
BYGDSB = 317
CBFEGZ = "".join(chr(c) for c in [79, 78])
CGETIX = "".join(chr(c) for c in [67, 70, 71, 49, 49])
CHWDAF = 347
CMCVDS = 469
CPQIPO = "".join(chr(c) for c in [66, 76])
CQBMJV = 261
CQFFTT = "".join(
    chr(c)
    for c in [82, 104, 78, 111, 116, 69, 110, 111, 117, 103, 104, 72, 101, 97, 116]
)
CRTFMN = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
CTHBSK = 298
CVDSSR = 470
CVYYPI = "".join(chr(c) for c in [72, 50])
CWAONP = 358
CXQIEF = "".join(chr(c) for c in [79, 117, 116, 50, 65, 82, 101, 97, 100])
DAFIKJ = "".join(chr(c) for c in [75, 50, 48, 48])
DFSROG = 479
DGKEAK = 453
DJQRJJ = 321
DKHTZB = 477
DNIBXT = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
DNQGVU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
DQLAII = "".join(chr(c) for c in [114, 72, 73, 100])
DSBDJQ = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
DSSRUR = 471
DUBSSU = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 80, 114])
DZXNQT = "".join(chr(c) for c in [67, 70, 71, 49])
EAKSTS = "".join(chr(c) for c in [67, 70, 71, 55])
ECVYYP = "".join(chr(c) for c in [72, 49])
EFJTAC = "".join(chr(c) for c in [80, 51])
EFXQGL = "".join(chr(c) for c in [79, 117, 116, 51, 65, 82, 101, 97, 100])
EGZUQE = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
EJNIBX = 270
EKCWAO = 304
EKVKZI = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
ELHBQN = 341
EMCGET = "".join(chr(c) for c in [67, 70, 71, 49, 48])
EOCTHB = 296
ETIXQV = "".join(chr(c) for c in [67, 70, 71, 49, 50])
EUTOPH = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
FCRTFM = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
FEFJTA = "".join(chr(c) for c in [80, 50])
FEGZUQ = 8
FFTTID = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121, 69, 114, 114])
FIKJPU = "".join(chr(c) for c in [75, 56, 53])
FJBIAM = 311
FJTACC = "".join(chr(c) for c in [80, 52])
FMNHTB = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
FTHECV = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
FTSIFJ = "".join(chr(c) for c in [79, 110, 122, 101, 110, 65, 99, 99, 101, 115, 115])
FTTIDU = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 82, 101, 116, 114, 121]
)
FXQGLR = 288
FYLJUI = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
FZDGKE = 452
GDSBDJ = 319
GETIXQ = 459
GKEAKS = "".join(chr(c) for c in [67, 70, 71, 54])
GLRAHE = "".join(chr(c) for c in [79, 117, 116, 53, 65, 82, 101, 97, 100])
GQPLSP = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
GSELHB = 339
GTYIYW = 327
GVUNXN = 333
GZUQEX = 1
HBQNRX = 343
HBSKSO = 362
HBVWVU = "".join(chr(c) for c in [82, 104, 72, 87, 75, 105, 110])
HBXIBH = 464
HECVYY = "".join(chr(c) for c in [83, 50])
HEOCTH = "".join(chr(c) for c in [79, 117, 116, 55, 65, 82, 101, 97, 100])
HFTHEC = 353
HIUSOO = 2
HTBJEU = "".join(chr(c) for c in [51, 50, 75])
HTZBBE = 478
HUGTYI = 325
HUOJRJ = "".join(chr(c) for c in [85, 100, 80, 49])
HWDAFI = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
HXEKVK = 278
HZVOAC = "".join(chr(c) for c in [67, 70, 71, 49, 57])
IACQFF = 365
IAMJMA = 313
IBHZVO = "".join(chr(c) for c in [67, 70, 71, 49, 56])
IBXTIA = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
IBXYBQ = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
ICXQIE = 282
IDNIBX = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
IDUBSS = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
IEFXQG = 286
IFJBIA = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 79, 110, 122, 101, 110, 68, 117, 114]
)
IGYOUS = "".join(chr(c) for c in [70, 85, 76, 76])
IHBXIB = "".join(chr(c) for c in [67, 70, 71, 49, 54])
IIDNIB = 258
IJUGSE = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 108])
IKFWRK = "".join(chr(c) for c in [78, 79])
IKJPUN = "".join(chr(c) for c in [75, 56])
ILXWAJ = "".join(
    chr(c)
    for c in [
        78,
        111,
        72,
        101,
        97,
        116,
        101,
        114,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
        69,
        114,
        114,
    ]
)
INEJNI = 265
IPIVLA = "".join(chr(c) for c in [76, 101, 97, 114, 110, 105, 110, 103])
IPOUYN = 3
IRYXBQ = "".join(chr(c) for c in [80, 117, 114, 103, 101])
IUSOOQ = 4
IUXFEF = "".join(chr(c) for c in [72, 73, 71, 72])
IVDNQG = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
IVLASS = "".join(chr(c) for c in [80, 104, 97, 115, 101, 83, 101, 108, 101, 99, 116])
IXQVXO = "".join(chr(c) for c in [67, 70, 71, 49, 51])
IYWSKW = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
JBIAMJ = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
JHIUSO = 14
JIGYOU = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
JJJVYF = "".join(chr(c) for c in [77, 73, 65])
JJVYFC = "".join(chr(c) for c in [68, 74, 83, 52])
JMAOAW = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
JMCBFE = 9
JNIBXY = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
JPUNRJ = "".join(chr(c) for c in [75, 53])
JQRJJJ = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
JRJHIU = "".join(chr(c) for c in [72, 73])
JTACCP = 6
JUGSEL = 338
JUIKFW = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
JUTYEK = "".join(chr(c) for c in [85, 100, 83, 112, 107, 114, 76, 105, 102, 116])
JVDQLA = "".join(chr(c) for c in [83, 117, 112, 112, 108, 121, 69, 114, 114])
JVHFTH = 256
JVYFCR = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
JWMNZM = 305
JYKLGQ = "".join(chr(c) for c in [73, 68, 76, 69])
JYMOUN = "".join(chr(c) for c in [85, 80])
JZTATD = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
KCWAON = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
KEAKST = 454
KFWRKI = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
KHTZBB = "".join(chr(c) for c in [67, 70, 71, 51, 48])
KINEJN = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
KJPUNR = "".join(chr(c) for c in [75, 52])
KLGQPL = "".join(chr(c) for c in [83, 84, 65, 82, 84])
KMLOIJ = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 73, 68])
KQTDKH = "".join(chr(c) for c in [67, 70, 71, 50, 56])
KQXPIC = 300
KSOKPH = "".join(chr(c) for c in [68, 82, 65, 73, 78])
KSTSEM = "".join(chr(c) for c in [67, 70, 71, 56])
KVKZIL = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
KWIVDN = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
KXSJWM = "".join(chr(c) for c in [86, 115, 112, 49, 70, 114, 111, 110, 116])
KZILXW = "".join(
    chr(c) for c in [70, 114, 101, 113, 68, 101, 116, 101, 99, 69, 114, 114]
)
LAIIDN = 260
LASSAK = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
LGQPLS = "".join(chr(c) for c in [78, 69, 87])
LHBQNR = "".join(chr(c) for c in [75, 54, 48, 48, 73, 68])
LIUXFE = 356
LJUIKF = 267
LKXSJW = 274
LNMHXE = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
LOIJUG = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 118])
LRAHEO = 292
LSPFTS = 308
LSXUJU = "".join(chr(c) for c in [85, 100, 86, 97, 108, 118, 101])
LXWAJV = "".join(
    chr(c) for c in [76, 101, 97, 114, 110, 80, 104, 97, 115, 101, 69, 114, 114]
)
MAOAWB = 350
MCBFEG = "".join(chr(c) for c in [85, 100, 66, 76])
MCGETI = 458
MCVDSS = "".join(chr(c) for c in [67, 70, 71, 50, 50])
MFZDGK = "".join(chr(c) for c in [67, 70, 71, 52])
MHXEKV = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
MJIGYO = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
MJMAOA = 314
MJVHFT = "".join(chr(c) for c in [72, 111, 117, 114, 115])
MKQTDK = 475
MLOIJU = 335
MNHTBJ = 322
MNZMJI = 302
MOUNBL = "".join(chr(c) for c in [83, 112, 107, 114, 76, 105, 102, 116])
NBLKXS = "".join(chr(c) for c in [86, 97, 108, 118, 101])
NEJNIB = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
NHTBJE = "".join(chr(c) for c in [49, 54, 75])
NIBXTI = 257
NIBXYB = 349
NMHXEK = 277
NPYYLI = 360
NQGVUN = 332
NQJYMO = "".join(chr(c) for c in [84, 118, 76, 105, 102, 116])
NQLNMH = "".join(chr(c) for c in [67, 111, 111, 108, 105, 110, 103, 68, 111, 119, 110])
NQTMFZ = 450
NRJZTA = "".join(chr(c) for c in [75, 56, 48, 48])
NRSJMC = "".join(chr(c) for c in [85, 100, 80, 52])
NRXCHW = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 108])
NXNKML = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
NZMJIG = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
OACMCV = 468
OAWBSI = 351
OCTHBS = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 82, 101, 97, 100])
OIHBXI = 463
OIJUGS = 337
OJRJHI = "".join(chr(c) for c in [76, 79])
OKPHUO = "".join(chr(c) for c in [79, 70, 70])
ONPYYL = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
OOQNRS = "".join(chr(c) for c in [85, 100, 80, 51])
OUNBLK = "".join(chr(c) for c in [83, 97, 110, 105])
OUSPBW = 348
OUYNQJ = "".join(chr(c) for c in [70, 65, 78])
PFTSIF = 316
PHUGTY = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
PHUOJR = "".join(chr(c) for c in [65, 76, 76])
PICXQI = "".join(chr(c) for c in [79, 117, 116, 49, 66, 82, 101, 97, 100])
PIPIVL = "".join(chr(c) for c in [76, 101, 97, 114, 110, 70, 97, 105, 108])
PIVLAS = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 108, 101, 99, 116]
)
PLSPFT = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
POUYNQ = "".join(chr(c) for c in [76, 49, 50, 48])
PQIPOU = "".join(chr(c) for c in [67, 80])
PUNRJZ = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
PYYLIU = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
QBMJVH = "".join(chr(c) for c in [82, 104, 84, 114, 105, 97, 99, 84, 101, 109, 112])
QEXLSX = "".join(chr(c) for c in [77, 69, 68])
QFFTTI = "".join(chr(c) for c in [82, 104, 76, 111, 119, 70, 108, 111])
QFYLJU = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
QGLRAH = 290
QGVUNX = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
QIEFXQ = "".join(chr(c) for c in [79, 117, 116, 50, 66, 82, 101, 97, 100])
QIPOUY = "".join(chr(c) for c in [79, 51])
QJYMOU = "".join(chr(c) for c in [68, 79, 87, 78])
QLAIID = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
QLNMHX = "".join(
    chr(c) for c in [75, 105, 110, 80, 117, 114, 103, 101, 65, 99, 116, 105, 118, 101]
)
QNRSJM = 11
QNRXCH = 345
QRJJJV = "".join(chr(c) for c in [105, 110, 88, 69])
QSNQLN = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
QTDKHT = 476
QTMFZD = "".join(chr(c) for c in [67, 70, 71, 51])
QVXOIH = "".join(chr(c) for c in [67, 70, 71, 49, 52])
QXPICX = "".join(chr(c) for c in [79, 117, 116, 49, 65, 82, 101, 97, 100])
RAHEOC = "".join(chr(c) for c in [79, 117, 116, 54, 65, 82, 101, 97, 100])
RAZMKQ = "".join(chr(c) for c in [67, 70, 71, 50, 54])
RJJJVY = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
RJZTAT = "".join(chr(c) for c in [])
RKINEJ = 272
RSJMCB = 10
RTFMNH = "".join(chr(c) for c in [105, 110, 89, 84])
RURAZM = "".join(chr(c) for c in [67, 70, 71, 50, 53])
RXCHWD = 346
RYXBQF = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
SBDJQR = 320
SELHBQ = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 70, 117, 108, 108]
)
SEMCGE = 457
SIFJBI = 310
SIRYXB = 269
SJMCBF = "".join(chr(c) for c in [85, 100, 80, 53])
SJWMNZ = "".join(chr(c) for c in [86, 115, 112, 49, 77, 105, 110])
SKSOKP = "".join(chr(c) for c in [81, 85, 73, 69, 84])
SKWIVD = 323
SNQLNM = "".join(chr(c) for c in [80, 117, 109, 112, 82, 117, 110])
SOKPHU = "".join(chr(c) for c in [83, 79, 65, 75])
SOOQNR = 12
SPBWJY = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
SPFTSI = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
SRURAZ = 472
SSAKQX = "".join(chr(c) for c in [80, 111, 119, 101, 114, 117, 112])
SSRURA = "".join(chr(c) for c in [67, 70, 71, 50, 52])
SSUHBV = "".join(chr(c) for c in [82, 104, 72, 119, 84, 114, 105, 97, 99, 79, 72])
STSEMC = 456
SUHBVW = "".join(chr(c) for c in [82, 104, 72, 114, 75, 105, 110])
SXUJUT = 7
TACCPQ = "".join(chr(c) for c in [80, 53])
TBJEUT = "".join(chr(c) for c in [52, 56, 75])
TDKHTZ = "".join(chr(c) for c in [67, 70, 71, 50, 57])
TDZXNQ = 448
THBSKS = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
THECVY = "".join(chr(c) for c in [83, 49])
TIACQF = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
TIDUBS = "".join(chr(c) for c in [82, 104, 72, 114, 72, 76])
TIXQVX = 460
TMFZDG = 451
TOPHUG = "".join(chr(c) for c in [67, 69])
TSEMCG = "".join(chr(c) for c in [67, 70, 71, 57])
TSIFJB = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        79,
        110,
        122,
        101,
        110,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
TTIDUB = "".join(chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 84, 101, 109, 112])
TYEKCW = 303
TYIYWS = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
TZBBEK = "".join(chr(c) for c in [67, 70, 71, 51, 49])
UBSSUH = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 79, 72])
UBYGDS = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
UGSELH = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 49, 75, 87]
)
UGTYIY = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
UHBVWV = "".join(chr(c) for c in [82, 104, 83, 119, 75, 105, 110, 84, 101, 109, 112])
UIKFWR = 268
UJUTYE = 5
UNBLKX = "".join(chr(c) for c in [79, 110, 122, 101, 110])
UNRJZT = "".join(chr(c) for c in [75, 49, 48, 48])
UNXNKM = 357
UOJRJH = 275
UQEXLS = 306
URAZMK = 473
USOOQN = "".join(chr(c) for c in [85, 100, 80, 50])
USPBWJ = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
UTOPHU = "".join(chr(c) for c in [85, 76])
UTYEKC = "".join(chr(c) for c in [85, 100, 86, 83, 80, 49])
UXFEFJ = "".join(chr(c) for c in [76, 79, 87])
UYNQJY = "".join(chr(c) for c in [65, 108, 119, 97, 121, 79, 110])
VDNQGV = 331
VDQLAI = "".join(chr(c) for c in [83, 99, 97, 110, 69, 114, 114])
VDSSRU = "".join(chr(c) for c in [67, 70, 71, 50, 51])
VHFTHE = "".join(chr(c) for c in [77, 101, 110, 117])
VKZILX = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
VLASSA = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
VOACMC = "".join(chr(c) for c in [67, 70, 71, 50, 48])
VUBYGD = "".join(
    chr(c)
    for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107, 82, 101, 97, 100, 121]
)
VUNXNK = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
VWVUBY = "".join(chr(c) for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107])
VXOIHB = 462
VYFCRT = "".join(chr(c) for c in [105, 110, 88, 77])
VYYPIP = "".join(chr(c) for c in [72, 51])
WAJVDQ = "".join(chr(c) for c in [70, 117, 115, 101, 50, 69, 114, 114])
WAONPY = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
WBSIRY = 352
WDAFIK = 367
WIVDNQ = 329
WJYKLG = 307
WMNZMJ = "".join(chr(c) for c in [86, 83, 80, 51, 70, 114, 111, 110, 116])
WRKINE = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
WSKWIV = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
WVUBYG = "".join(
    chr(c)
    for c in [
        82,
        104,
        72,
        101,
        97,
        116,
        101,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
    ]
)
XBQFYL = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
XCHWDA = "".join(chr(c) for c in [75, 54, 48, 48, 80, 114, 111, 116, 111, 99, 111, 108])
XEKVKZ = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 49]
)
XIBHZV = 465
XLSXUJ = 0
XNKMLO = "".join(chr(c) for c in [70, 117, 108, 108])
XNQTMF = "".join(chr(c) for c in [67, 70, 71, 50])
XOIHBX = "".join(chr(c) for c in [67, 70, 71, 49, 53])
XPICXQ = 280
XQGLRA = "".join(chr(c) for c in [79, 117, 116, 52, 65, 82, 101, 97, 100])
XQIEFX = 284
XQVXOI = 461
XSJWMN = 301
XTIACQ = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
XUJUTY = "".join(chr(c) for c in [85, 100, 84, 118, 76, 105, 102, 116])
XWAJVD = "".join(chr(c) for c in [70, 117, 115, 101, 51, 69, 114, 114])
XYBQSN = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
YBQSNQ = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
YEKCWA = "".join(chr(c) for c in [85, 100, 86, 83, 80, 51])
YFCRTF = "".join(chr(c) for c in [75, 54, 48, 48])
YGDSBD = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
YIYWSK = 328
YKLGQP = "".join(chr(c) for c in [83, 84, 79, 80])
YLIUXF = "".join(chr(c) for c in [80, 49])
YLJUIK = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
YNQJYM = 354
YOUSPB = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
YPIPIV = "".join(chr(c) for c in [70, 114])
YWSKWI = 324
YXBQFY = 279
YYLIUX = 361
YYPIPI = "".join(chr(c) for c in [72, 52])
ZBBEKB = 479
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = "".join(chr(c) for c in [67, 70, 71, 53])
ZILXWA = "".join(
    chr(c)
    for c in [
        67,
        111,
        110,
        116,
        97,
        99,
        116,
        111,
        114,
        67,
        111,
        105,
        108,
        70,
        97,
        105,
        108,
        69,
        114,
        114,
    ]
)
ZMJIGY = 363
ZMKQTD = "".join(chr(c) for c in [67, 70, 71, 50, 55])
ZTATDZ = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
ZUQEXL = "".join(chr(c) for c in [85, 100, 76, 105])
ZVOACM = 467
ZXNQTM = 449
BBEKBD = []
BFEGZU = [OKPHUO, CBFEGZ]
CCPQIP = [OKPHUO, IUXFEF]
EKBDFS = [
    YLIUXF,
    FEFJTA,
    EFJTAC,
    FJTACC,
    TACCPQ,
    CPQIPO,
    PQIPOU,
    QIPOUY,
    POUYNQ,
    OUYNQJ,
    UYNQJY,
    NQJYMO,
    MOUNBL,
    OUNBLK,
    UNBLKX,
    NBLKXS,
    BLKXSJ,
    KXSJWM,
    SJWMNZ,
    WMNZMJ,
    NZMJIG,
    BEKBDF,
]
EXLSXU = [OKPHUO, OJRJHI, QEXLSX, JRJHIU]
FWRKIN = [IKFWRK, OJRJHI, QEXLSX, JRJHIU, KFWRKI]
GYOUSP = [MJIGYO, JIGYOU, IGYOUS]
JEUTOP = [NHTBJE, HTBJEU, TBJEUT, BJEUTO]
KBDFSR = [
    HUOJRJ,
    USOOQN,
    OOQNRS,
    NRSJMC,
    SJMCBF,
    MCBFEG,
    EGZUQE,
    ZUQEXL,
    LSXUJU,
    XUJUTY,
    JUTYEK,
    UTYEKC,
    YEKCWA,
    KCWAON,
    WAONPY,
    ONPYYL,
    PYYLIU,
]
KPHUOJ = [BSKSOK, SKSOKP, KSOKPH, SOKPHU, OKPHUO]
NKMLOI = [NXNKML, XNKMLO]
OPHUGT = [UTOPHU, TOPHUG]
OQNRSJ = [OKPHUO, JRJHIU]
PBWJYK = [USPBWJ, SPBWJY]
QPLSPF = [JYKLGQ, YKLGQP, KLGQPL, LGQPLS, GQPLSP]
RJHIUS = [OKPHUO, OJRJHI, JRJHIU]
SAKQXP = [
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
]
TATDZX = [
    DAFIKJ,
    AFIKJP,
    FIKJPU,
    IKJPUN,
    KJPUNR,
    JPUNRJ,
    PUNRJZ,
    UNRJZT,
    NRJZTA,
    RJZTAT,
    RJZTAT,
    RJZTAT,
    JZTATD,
    ZTATDZ,
]
TFMNHT = [
    JQRJJJ,
    QRJJJV,
    RJJJVY,
    JJJVYF,
    JJVYFC,
    JVYFCR,
    VYFCRT,
    YFCRTF,
    FCRTFM,
    CRTFMN,
    RTFMNH,
]
XFEFJT = [OKPHUO, IUXFEF, UXFEFJ]
YMOUNB = [QJYMOU, JYMOUN]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return FEGZUQ

    @property
    def begin(self):
        return BDFSRO

    @property
    def end(self):
        return DFSROG

    @property
    def all_device_keys(self):
        return EKBDFS

    @property
    def user_demand_keys(self):
        return KBDFSR

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoTempStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoByteStructAccessor(self.struct, MJVHFT, JVHFTH, None),
            VHFTHE: GeckoEnumStructAccessor(
                self.struct, VHFTHE, HFTHEC, None, SAKQXP, None, None, None
            ),
            AKQXPI: GeckoByteStructAccessor(self.struct, AKQXPI, KQXPIC, None),
            QXPICX: GeckoWordStructAccessor(self.struct, QXPICX, XPICXQ, None),
            PICXQI: GeckoWordStructAccessor(self.struct, PICXQI, ICXQIE, None),
            CXQIEF: GeckoWordStructAccessor(self.struct, CXQIEF, XQIEFX, None),
            QIEFXQ: GeckoWordStructAccessor(self.struct, QIEFXQ, IEFXQG, None),
            EFXQGL: GeckoWordStructAccessor(self.struct, EFXQGL, FXQGLR, None),
            XQGLRA: GeckoWordStructAccessor(self.struct, XQGLRA, QGLRAH, None),
            GLRAHE: GeckoWordStructAccessor(self.struct, GLRAHE, LRAHEO, None),
            RAHEOC: GeckoWordStructAccessor(self.struct, RAHEOC, AHEOCT, None),
            HEOCTH: GeckoWordStructAccessor(self.struct, HEOCTH, EOCTHB, None),
            OCTHBS: GeckoWordStructAccessor(self.struct, OCTHBS, CTHBSK, None),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, None, KPHUOJ, None, None, PHUOJR
            ),
            HUOJRJ: GeckoEnumStructAccessor(
                self.struct, HUOJRJ, UOJRJH, JHIUSO, RJHIUS, HIUSOO, IUSOOQ, PHUOJR
            ),
            USOOQN: GeckoEnumStructAccessor(
                self.struct, USOOQN, UOJRJH, SOOQNR, RJHIUS, HIUSOO, IUSOOQ, PHUOJR
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, UOJRJH, QNRSJM, OQNRSJ, HIUSOO, HIUSOO, PHUOJR
            ),
            NRSJMC: GeckoEnumStructAccessor(
                self.struct, NRSJMC, UOJRJH, RSJMCB, OQNRSJ, HIUSOO, HIUSOO, PHUOJR
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, UOJRJH, JMCBFE, OQNRSJ, HIUSOO, HIUSOO, PHUOJR
            ),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, UOJRJH, FEGZUQ, BFEGZU, HIUSOO, HIUSOO, PHUOJR
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, UOJRJH, GZUQEX, BFEGZU, HIUSOO, HIUSOO, PHUOJR
            ),
            ZUQEXL: GeckoEnumStructAccessor(
                self.struct, ZUQEXL, UQEXLS, XLSXUJ, EXLSXU, None, IUSOOQ, PHUOJR
            ),
            LSXUJU: GeckoEnumStructAccessor(
                self.struct, LSXUJU, UOJRJH, SXUJUT, BFEGZU, HIUSOO, HIUSOO, PHUOJR
            ),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, UOJRJH, UJUTYE, BFEGZU, HIUSOO, HIUSOO, PHUOJR
            ),
            JUTYEK: GeckoEnumStructAccessor(
                self.struct, JUTYEK, UOJRJH, IUSOOQ, BFEGZU, HIUSOO, HIUSOO, PHUOJR
            ),
            UTYEKC: GeckoByteStructAccessor(self.struct, UTYEKC, TYEKCW, PHUOJR),
            YEKCWA: GeckoByteStructAccessor(self.struct, YEKCWA, EKCWAO, PHUOJR),
            KCWAON: GeckoByteStructAccessor(self.struct, KCWAON, CWAONP, PHUOJR),
            WAONPY: GeckoByteStructAccessor(self.struct, WAONPY, AONPYY, PHUOJR),
            ONPYYL: GeckoByteStructAccessor(self.struct, ONPYYL, NPYYLI, PHUOJR),
            PYYLIU: GeckoByteStructAccessor(self.struct, PYYLIU, YYLIUX, PHUOJR),
            YLIUXF: GeckoEnumStructAccessor(
                self.struct, YLIUXF, LIUXFE, XLSXUJ, XFEFJT, None, IUSOOQ, None
            ),
            FEFJTA: GeckoEnumStructAccessor(
                self.struct, FEFJTA, LIUXFE, HIUSOO, XFEFJT, None, IUSOOQ, None
            ),
            EFJTAC: GeckoEnumStructAccessor(
                self.struct, EFJTAC, LIUXFE, IUSOOQ, XFEFJT, None, IUSOOQ, None
            ),
            FJTACC: GeckoEnumStructAccessor(
                self.struct, FJTACC, LIUXFE, JTACCP, XFEFJT, None, IUSOOQ, None
            ),
            TACCPQ: GeckoEnumStructAccessor(
                self.struct, TACCPQ, ACCPQI, XLSXUJ, CCPQIP, None, HIUSOO, None
            ),
            CPQIPO: GeckoEnumStructAccessor(
                self.struct, CPQIPO, ACCPQI, GZUQEX, BFEGZU, None, HIUSOO, None
            ),
            PQIPOU: GeckoEnumStructAccessor(
                self.struct, PQIPOU, ACCPQI, HIUSOO, BFEGZU, None, HIUSOO, None
            ),
            QIPOUY: GeckoEnumStructAccessor(
                self.struct, QIPOUY, ACCPQI, IPOUYN, BFEGZU, None, HIUSOO, None
            ),
            POUYNQ: GeckoEnumStructAccessor(
                self.struct, POUYNQ, ACCPQI, IUSOOQ, BFEGZU, None, HIUSOO, None
            ),
            OUYNQJ: GeckoEnumStructAccessor(
                self.struct, OUYNQJ, ACCPQI, SXUJUT, BFEGZU, None, HIUSOO, None
            ),
            UYNQJY: GeckoEnumStructAccessor(
                self.struct, UYNQJY, YNQJYM, HIUSOO, BFEGZU, None, HIUSOO, None
            ),
            NQJYMO: GeckoEnumStructAccessor(
                self.struct, NQJYMO, YNQJYM, IPOUYN, YMOUNB, None, HIUSOO, None
            ),
            MOUNBL: GeckoEnumStructAccessor(
                self.struct, MOUNBL, YNQJYM, IUSOOQ, YMOUNB, None, HIUSOO, None
            ),
            OUNBLK: GeckoEnumStructAccessor(
                self.struct, OUNBLK, YNQJYM, UJUTYE, BFEGZU, None, HIUSOO, None
            ),
            UNBLKX: GeckoEnumStructAccessor(
                self.struct, UNBLKX, YNQJYM, JTACCP, BFEGZU, None, HIUSOO, None
            ),
            NBLKXS: GeckoEnumStructAccessor(
                self.struct, NBLKXS, YNQJYM, SXUJUT, BFEGZU, None, HIUSOO, None
            ),
            BLKXSJ: GeckoByteStructAccessor(self.struct, BLKXSJ, LKXSJW, None),
            KXSJWM: GeckoByteStructAccessor(self.struct, KXSJWM, XSJWMN, None),
            SJWMNZ: GeckoByteStructAccessor(self.struct, SJWMNZ, JWMNZM, None),
            WMNZMJ: GeckoByteStructAccessor(self.struct, WMNZMJ, MNZMJI, None),
            NZMJIG: GeckoEnumStructAccessor(
                self.struct, NZMJIG, ZMJIGY, None, GYOUSP, None, None, PHUOJR
            ),
            YOUSPB: GeckoEnumStructAccessor(
                self.struct, YOUSPB, OUSPBW, XLSXUJ, PBWJYK, None, HIUSOO, PHUOJR
            ),
            BWJYKL: GeckoEnumStructAccessor(
                self.struct, BWJYKL, WJYKLG, None, QPLSPF, None, None, PHUOJR
            ),
            PLSPFT: GeckoTimeStructAccessor(self.struct, PLSPFT, LSPFTS, PHUOJR),
            SPFTSI: GeckoByteStructAccessor(self.struct, SPFTSI, PFTSIF, PHUOJR),
            FTSIFJ: GeckoEnumStructAccessor(
                self.struct, FTSIFJ, OUSPBW, GZUQEX, PBWJYK, None, HIUSOO, PHUOJR
            ),
            TSIFJB: GeckoEnumStructAccessor(
                self.struct, TSIFJB, SIFJBI, None, QPLSPF, None, None, PHUOJR
            ),
            IFJBIA: GeckoTimeStructAccessor(self.struct, IFJBIA, FJBIAM, PHUOJR),
            JBIAMJ: GeckoEnumStructAccessor(
                self.struct, JBIAMJ, OUSPBW, HIUSOO, PBWJYK, None, HIUSOO, PHUOJR
            ),
            BIAMJM: GeckoEnumStructAccessor(
                self.struct, BIAMJM, IAMJMA, None, QPLSPF, None, None, PHUOJR
            ),
            AMJMAO: GeckoTimeStructAccessor(self.struct, AMJMAO, MJMAOA, PHUOJR),
            JMAOAW: GeckoByteStructAccessor(self.struct, JMAOAW, MAOAWB, PHUOJR),
            AOAWBS: GeckoByteStructAccessor(self.struct, AOAWBS, OAWBSI, PHUOJR),
            AWBSIR: GeckoByteStructAccessor(self.struct, AWBSIR, WBSIRY, PHUOJR),
            BSIRYX: GeckoBoolStructAccessor(self.struct, BSIRYX, SIRYXB, UJUTYE, None),
            IRYXBQ: GeckoBoolStructAccessor(self.struct, IRYXBQ, SIRYXB, SXUJUT, None),
            RYXBQF: GeckoBoolStructAccessor(self.struct, RYXBQF, YXBQFY, IPOUYN, None),
            XBQFYL: GeckoBoolStructAccessor(self.struct, XBQFYL, YXBQFY, XLSXUJ, None),
            BQFYLJ: GeckoBoolStructAccessor(self.struct, BQFYLJ, YXBQFY, GZUQEX, None),
            QFYLJU: GeckoBoolStructAccessor(self.struct, QFYLJU, SIRYXB, HIUSOO, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, SIRYXB, IPOUYN, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, LJUIKF, None, None),
            JUIKFW: GeckoEnumStructAccessor(
                self.struct, JUIKFW, UIKFWR, None, FWRKIN, None, None, None
            ),
            WRKINE: GeckoTempStructAccessor(self.struct, WRKINE, RKINEJ, None),
            KINEJN: GeckoTempStructAccessor(self.struct, KINEJN, INEJNI, None),
            NEJNIB: GeckoBoolStructAccessor(self.struct, NEJNIB, EJNIBX, SXUJUT, None),
            JNIBXY: GeckoBoolStructAccessor(self.struct, JNIBXY, NIBXYB, GZUQEX, None),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, BXYBQS, XLSXUJ, None),
            XYBQSN: GeckoBoolStructAccessor(self.struct, XYBQSN, SIRYXB, XLSXUJ, None),
            YBQSNQ: GeckoBoolStructAccessor(self.struct, YBQSNQ, BQSNQL, HIUSOO, None),
            QSNQLN: GeckoBoolStructAccessor(
                self.struct, QSNQLN, BQSNQL, XLSXUJ, PHUOJR
            ),
            SNQLNM: GeckoBoolStructAccessor(self.struct, SNQLNM, SIRYXB, GZUQEX, None),
            NQLNMH: GeckoBoolStructAccessor(self.struct, NQLNMH, EJNIBX, JTACCP, None),
            QLNMHX: GeckoBoolStructAccessor(self.struct, QLNMHX, EJNIBX, UJUTYE, None),
            LNMHXE: GeckoBoolStructAccessor(self.struct, LNMHXE, NMHXEK, UJUTYE, None),
            MHXEKV: GeckoBoolStructAccessor(self.struct, MHXEKV, HXEKVK, IPOUYN, None),
            XEKVKZ: GeckoBoolStructAccessor(self.struct, XEKVKZ, HXEKVK, HIUSOO, None),
            EKVKZI: GeckoBoolStructAccessor(self.struct, EKVKZI, YXBQFY, IUSOOQ, None),
            KVKZIL: GeckoBoolStructAccessor(self.struct, KVKZIL, HXEKVK, IUSOOQ, None),
            VKZILX: GeckoBoolStructAccessor(self.struct, VKZILX, HXEKVK, GZUQEX, None),
            KZILXW: GeckoBoolStructAccessor(self.struct, KZILXW, NMHXEK, JTACCP, None),
            ZILXWA: GeckoBoolStructAccessor(self.struct, ZILXWA, NMHXEK, IUSOOQ, None),
            ILXWAJ: GeckoBoolStructAccessor(self.struct, ILXWAJ, NMHXEK, IPOUYN, None),
            LXWAJV: GeckoBoolStructAccessor(self.struct, LXWAJV, NMHXEK, HIUSOO, None),
            XWAJVD: GeckoBoolStructAccessor(self.struct, XWAJVD, NMHXEK, GZUQEX, None),
            WAJVDQ: GeckoBoolStructAccessor(self.struct, WAJVDQ, NMHXEK, XLSXUJ, None),
            AJVDQL: GeckoBoolStructAccessor(self.struct, AJVDQL, HXEKVK, SXUJUT, None),
            JVDQLA: GeckoBoolStructAccessor(self.struct, JVDQLA, HXEKVK, JTACCP, None),
            VDQLAI: GeckoBoolStructAccessor(self.struct, VDQLAI, HXEKVK, UJUTYE, None),
            DQLAII: GeckoBoolStructAccessor(self.struct, DQLAII, HXEKVK, XLSXUJ, None),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, LAIIDN, IPOUYN, None),
            AIIDNI: GeckoBoolStructAccessor(self.struct, AIIDNI, IIDNIB, HIUSOO, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, IIDNIB, GZUQEX, None),
            DNIBXT: GeckoBoolStructAccessor(self.struct, DNIBXT, NIBXTI, HIUSOO, None),
            IBXTIA: GeckoBoolStructAccessor(self.struct, IBXTIA, BXTIAC, HIUSOO, None),
            XTIACQ: GeckoBoolStructAccessor(self.struct, XTIACQ, IIDNIB, IUSOOQ, None),
            TIACQF: GeckoWordStructAccessor(self.struct, TIACQF, IACQFF, None),
            ACQFFT: GeckoBoolStructAccessor(self.struct, ACQFFT, NIBXTI, SXUJUT, None),
            CQFFTT: GeckoBoolStructAccessor(self.struct, CQFFTT, NIBXTI, IPOUYN, None),
            QFFTTI: GeckoBoolStructAccessor(self.struct, QFFTTI, NIBXTI, XLSXUJ, None),
            FFTTID: GeckoBoolStructAccessor(self.struct, FFTTID, IIDNIB, SXUJUT, None),
            FTTIDU: GeckoBoolStructAccessor(self.struct, FTTIDU, IIDNIB, JTACCP, None),
            TTIDUB: GeckoBoolStructAccessor(self.struct, TTIDUB, IIDNIB, UJUTYE, None),
            TIDUBS: GeckoBoolStructAccessor(self.struct, TIDUBS, IIDNIB, IPOUYN, None),
            IDUBSS: GeckoBoolStructAccessor(self.struct, IDUBSS, IIDNIB, XLSXUJ, None),
            DUBSSU: GeckoBoolStructAccessor(self.struct, DUBSSU, BXTIAC, SXUJUT, None),
            UBSSUH: GeckoBoolStructAccessor(self.struct, UBSSUH, BXTIAC, JTACCP, None),
            BSSUHB: GeckoBoolStructAccessor(self.struct, BSSUHB, BXTIAC, UJUTYE, None),
            SSUHBV: GeckoBoolStructAccessor(self.struct, SSUHBV, BXTIAC, IUSOOQ, None),
            SUHBVW: GeckoBoolStructAccessor(self.struct, SUHBVW, BXTIAC, IPOUYN, None),
            UHBVWV: GeckoBoolStructAccessor(self.struct, UHBVWV, BXTIAC, GZUQEX, None),
            HBVWVU: GeckoBoolStructAccessor(self.struct, HBVWVU, BXTIAC, XLSXUJ, None),
            BVWVUB: GeckoBoolStructAccessor(self.struct, BVWVUB, LAIIDN, IUSOOQ, None),
            VWVUBY: GeckoBoolStructAccessor(self.struct, VWVUBY, LAIIDN, HIUSOO, None),
            WVUBYG: GeckoBoolStructAccessor(self.struct, WVUBYG, LAIIDN, GZUQEX, None),
            VUBYGD: GeckoBoolStructAccessor(self.struct, VUBYGD, LAIIDN, XLSXUJ, None),
            UBYGDS: GeckoWordStructAccessor(self.struct, UBYGDS, BYGDSB, None),
            YGDSBD: GeckoByteStructAccessor(self.struct, YGDSBD, GDSBDJ, None),
            DSBDJQ: GeckoByteStructAccessor(self.struct, DSBDJQ, SBDJQR, None),
            BDJQRJ: GeckoEnumStructAccessor(
                self.struct, BDJQRJ, DJQRJJ, None, TFMNHT, None, None, None
            ),
            FMNHTB: GeckoEnumStructAccessor(
                self.struct, FMNHTB, MNHTBJ, XLSXUJ, JEUTOP, None, IUSOOQ, None
            ),
            EUTOPH: GeckoEnumStructAccessor(
                self.struct, EUTOPH, MNHTBJ, HIUSOO, OPHUGT, None, HIUSOO, None
            ),
            PHUGTY: GeckoWordStructAccessor(self.struct, PHUGTY, HUGTYI, None),
            UGTYIY: GeckoByteStructAccessor(self.struct, UGTYIY, GTYIYW, None),
            TYIYWS: GeckoByteStructAccessor(self.struct, TYIYWS, YIYWSK, None),
            IYWSKW: GeckoByteStructAccessor(self.struct, IYWSKW, YWSKWI, None),
            WSKWIV: GeckoByteStructAccessor(self.struct, WSKWIV, SKWIVD, None),
            KWIVDN: GeckoWordStructAccessor(self.struct, KWIVDN, WIVDNQ, None),
            IVDNQG: GeckoByteStructAccessor(self.struct, IVDNQG, VDNQGV, None),
            DNQGVU: GeckoByteStructAccessor(self.struct, DNQGVU, NQGVUN, None),
            QGVUNX: GeckoWordStructAccessor(self.struct, QGVUNX, GVUNXN, None),
            VUNXNK: GeckoEnumStructAccessor(
                self.struct, VUNXNK, UNXNKM, None, NKMLOI, None, HIUSOO, PHUOJR
            ),
            KMLOIJ: GeckoWordStructAccessor(self.struct, KMLOIJ, MLOIJU, None),
            LOIJUG: GeckoByteStructAccessor(self.struct, LOIJUG, OIJUGS, None),
            IJUGSE: GeckoByteStructAccessor(self.struct, IJUGSE, JUGSEL, None),
            UGSELH: GeckoWordStructAccessor(self.struct, UGSELH, GSELHB, None),
            SELHBQ: GeckoWordStructAccessor(self.struct, SELHBQ, ELHBQN, None),
            HWDAFI: GeckoEnumStructAccessor(
                self.struct, HWDAFI, WDAFIK, None, TATDZX, None, None, None
            ),
        }



#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InYJ-V2 v58'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = 268
ACMCVD = 473
ACQFFT = "".join(chr(c) for c in [53, 79, 80])
AHEOCT = 1
AIIDNI = "".join(chr(c) for c in [54, 52, 75])
AKQXPI = "".join(chr(c) for c in [85, 100, 80, 49])
AKSTSE = "".join(chr(c) for c in [67, 70, 71, 49, 50])
AMJMAO = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
AOAWBS = 350
AONPYY = 263
ASSAKQ = "".join(chr(c) for c in [79, 70, 70])
ATDZXN = 452
AWBSIR = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
AZMKQT = "".join(chr(c) for c in [67, 70, 71, 51, 49])
BDJQRJ = 300
BFEGZU = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
BHZVOA = "".join(chr(c) for c in [67, 70, 71, 50, 51])
BIAMJM = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
BJEUTO = "".join(chr(c) for c in [75, 51, 48, 48])
BLKXSJ = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
BMJVHF = 256
BQFYLJ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
BQNRXC = 329
BQSNQL = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
BSIRYX = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
BSKSOK = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
BSSUHB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
BVWVUB = 294
BWJYKL = 279
BXIBHZ = 469
BXTIAC = "".join(chr(c) for c in [80, 97, 99, 107, 88, 101, 80, 50, 50, 66, 76])
BXYBQS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
BYGDSB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
CBFEGZ = "".join(chr(c) for c in [76, 49, 50, 48])
CCPQIP = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
CGETIX = 463
CHWDAF = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
CMCVDS = "".join(chr(c) for c in [67, 70, 71, 50, 54])
CPQIPO = 270
CQBMJV = 317
CQFFTT = "".join(chr(c) for c in [51, 79, 80])
CRTFMN = "".join(chr(c) for c in [75, 52, 48, 48])
CTHBSK = 307
CVDSSR = "".join(chr(c) for c in [67, 70, 71, 50, 55])
CVYYPI = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
CXQIEF = 4
DAFIKJ = 325
DGKEAK = "".join(chr(c) for c in [67, 70, 71, 49, 48])
DJQRJJ = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
DKHTZB = 58
DNIBXT = "".join(chr(c) for c in [85, 76])
DNQGVU = "".join(chr(c) for c in [66, 76, 79])
DQLAII = "".join(chr(c) for c in [49, 54, 75])
DSBDJQ = 299
DSSRUR = "".join(chr(c) for c in [67, 70, 71, 50, 56])
DZXNQT = 453
EAKSTS = 459
ECVYYP = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
EFJTAC = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
EFXQGL = "".join(chr(c) for c in [85, 100, 80, 52])
EGZUQE = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
EJNIBX = 315
EKCWAO = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
EKVKZI = "".join(chr(c) for c in [68, 74, 83, 52])
ELHBQN = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
EMCGET = 462
EOCTHB = 308
ETIXQV = 464
EXLSXU = "".join(chr(c) for c in [70, 85, 76, 76])
FCRTFM = "".join(chr(c) for c in [75, 50, 48, 48])
FEFJTA = 266
FEGZUQ = 5
FFTTID = "".join(
    chr(c)
    for c in [
        80,
        97,
        99,
        107,
        88,
        101,
        67,
        69,
        65,
        99,
        99,
        79,
        110,
        70,
        117,
        115,
        101,
        50,
    ]
)
FIKJPU = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
FJBIAM = 283
FJTACC = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
FMNHTB = "".join(chr(c) for c in [75, 52])
FTHECV = 319
FTSIFJ = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
FTTIDU = "".join(chr(c) for c in [80, 97, 99, 107, 78, 111, 73, 110, 70, 108, 111])
FXQGLR = "".join(chr(c) for c in [85, 100, 80, 53])
FYLJUI = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
FZDGKE = "".join(chr(c) for c in [67, 70, 71, 57])
GDSBDJ = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
GETIXQ = "".join(chr(c) for c in [67, 70, 71, 49, 54])
GKEAKS = 458
GLRAHE = "".join(chr(c) for c in [85, 100, 66, 76])
GQPLSP = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
GSELHB = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
GTYIYW = "".join(chr(c) for c in [83, 79, 117, 116, 49])
GYOUSP = 275
GZUQEX = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
HBQNRX = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
HBSKSO = 370
HBVWVU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
HBXIBH = "".join(chr(c) for c in [67, 70, 71, 50, 49])
HECVYY = "".join(chr(c) for c in [])
HEOCTH = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
HFTHEC = "".join(chr(c) for c in [77, 101, 110, 117])
HIUSOO = "".join(chr(c) for c in [76, 79, 87])
HTBJEU = "".join(chr(c) for c in [75, 49, 48, 48])
HTZBBE = 479
HUGTYI = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
HUOJRJ = 306
HWDAFI = 333
HXEKVK = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
HZVOAC = 471
IACQFF = "".join(
    chr(c) for c in [80, 97, 99, 107, 88, 101, 79, 117, 116, 112, 117, 116, 115]
)
IAMJMA = 284
IBHZVO = 470
IBXYBQ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
ICXQIE = 0
IDNIBX = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
IDUBSS = "".join(chr(c) for c in [51, 48, 65])
IEFXQG = "".join(chr(c) for c in [85, 100, 80, 51])
IFJBIA = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
IGYOUS = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
IHBXIB = 468
IJUGSE = 326
IKFWRK = 309
IKJPUN = 332
ILXWAJ = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
INEJNI = 314
IPIVLA = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
IPOUYN = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
IRYXBQ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
IUXFEF = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
IVDNQG = "".join(chr(c) for c in [80, 52, 72])
IVLASS = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
IXQVXO = 465
IYWSKW = "".join(chr(c) for c in [80, 49, 72])
JBIAMJ = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
JEUTOP = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
JHIUSO = "".join(chr(c) for c in [72, 73, 71, 72])
JIGYOU = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
JJJVYF = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
JJVYFC = "".join(chr(c) for c in [70, 117, 108, 108])
JMAOAW = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
JMCBFE = "".join(chr(c) for c in [79, 51])
JNIBXY = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
JPUNRJ = 448
JQRJJJ = 301
JRJHIU = "".join(chr(c) for c in [80, 49])
JTACCP = 267
JUGSEL = "".join(chr(c) for c in [72, 84, 82])
JUIKFW = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
JUTYEK = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 75, 101, 121]
)
JVDQLA = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
JVHFTH = 274
JYKLGQ = 280
JYMOUN = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
JZTATD = "".join(chr(c) for c in [67, 70, 71, 51])
KCWAON = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
KEAKST = "".join(chr(c) for c in [67, 70, 71, 49, 49])
KFWRKI = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
KHTZBB = 256
KINEJN = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
KJPUNR = "".join(chr(c) for c in [67, 70, 71, 48])
KLGQPL = 281
KMLOIJ = 323
KPHUOJ = 305
KQTDKH = "".join(chr(c) for c in [76, 73])
KQXPIC = 259
KSOKPH = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
KSTSEM = 460
KVKZIL = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
KWIVDN = "".join(chr(c) for c in [80, 51, 72])
KXSJWM = "".join(chr(c) for c in [78, 79])
KZILXW = "".join(chr(c) for c in [75, 54, 48, 48])
LAIIDN = "".join(chr(c) for c in [52, 56, 75])
LASSAK = "".join(chr(c) for c in [83, 79, 65, 75])
LGQPLS = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
LHBQNR = 328
LJUIKF = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
LKXSJW = 313
LNMHXE = 289
LOIJUG = 324
LRAHEO = "".join(chr(c) for c in [79, 78])
LSPFTS = 377
LSXUJU = "".join(
    chr(c)
    for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 116, 97, 116, 117, 115]
)
LXWAJV = "".join(chr(c) for c in [105, 110, 89, 84])
MAOAWB = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
MCBFEG = 3
MCGETI = "".join(chr(c) for c in [67, 70, 71, 49, 53])
MCVDSS = 474
MFZDGK = 456
MHXEKV = "".join(chr(c) for c in [105, 110, 88, 69])
MJIGYO = 355
MJMAOA = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
MJVHFT = "".join(
    chr(c) for c in [83, 116, 105, 99, 107, 68, 101, 116, 101, 99, 116, 101, 100]
)
MLOIJU = "".join(chr(c) for c in [83, 79, 117, 116, 53])
MNHTBJ = "".join(chr(c) for c in [75, 53])
MNZMJI = 353
MOUNBL = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
NBLKXS = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
NEJNIB = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
NHTBJE = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
NIBXTI = "".join(chr(c) for c in [67, 69])
NIBXYB = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
NKMLOI = "".join(chr(c) for c in [83, 79, 117, 116, 52])
NMHXEK = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
NPYYLI = "".join(chr(c) for c in [83, 84, 79, 80])
NQGVUN = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
NQJYMO = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
NQLNMH = 288
NQTMFZ = "".join(chr(c) for c in [67, 70, 71, 55])
NRJZTA = "".join(chr(c) for c in [67, 70, 71, 50])
NRXCHW = 330
NXNKML = "".join(chr(c) for c in [83, 79, 117, 116, 51])
NZMJIG = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
OACMCV = "".join(chr(c) for c in [67, 70, 71, 50, 53])
OAWBSI = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
OCTHBS = "".join(chr(c) for c in [85, 100, 76, 105])
OIHBXI = "".join(chr(c) for c in [67, 70, 71, 50, 48])
OIJUGS = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
OJRJHI = 369
OKPHUO = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
ONPYYL = "".join(chr(c) for c in [73, 68, 76, 69])
OOQNRS = "".join(chr(c) for c in [80, 52])
OPHUGT = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
OQNRSJ = "".join(chr(c) for c in [80, 53])
OUNBLK = 282
OUSPBW = 277
OUYNQJ = "".join(chr(c) for c in [67, 108, 101, 97, 110])
PBWJYK = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
PFTSIF = 383
PHUGTY = 360
PHUOJR = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
PIVLAS = 257
PLSPFT = "".join(
    chr(c)
    for c in [83, 105, 100, 101, 72, 101, 97, 116, 105, 110, 103, 68, 101, 103, 71]
)
POUYNQ = 272
PQIPOU = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
PUNRJZ = "".join(chr(c) for c in [67, 70, 71, 49])
PYYLIU = "".join(chr(c) for c in [83, 84, 65, 82, 84])
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QEXLSX = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
QFYLJU = 354
QGVUNX = "".join(chr(c) for c in [65, 85, 88])
QIEFXQ = 2
QIPOUY = 271
QJYMOU = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
QLAIID = "".join(chr(c) for c in [51, 50, 75])
QLNMHX = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
QNRSJM = 260
QNRXCH = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
QPLSPF = 352
QRJJJV = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
QSNQLN = 287
QTMFZD = 455
QVXOIH = 466
QXPICX = "".join(chr(c) for c in [76, 79])
RAZMKQ = 478
RJHIUS = 261
RJJJVY = 316
RJZTAT = 450
RKINEJ = 311
RSJMCB = "".join(chr(c) for c in [66, 76])
RTFMNH = "".join(chr(c) for c in [75, 56, 53])
RURAZM = 477
RXCHWD = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
RYXBQF = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
SAKQXP = "".join(chr(c) for c in [65, 76, 76])
SBDJQR = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
SELHBQ = 327
SEMCGE = "".join(chr(c) for c in [67, 70, 71, 49, 52])
SIFJBI = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
SIRYXB = 351
SJMCBF = "".join(chr(c) for c in [67, 80])
SJWMNZ = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
SKSOKP = 303
SKWIVD = "".join(chr(c) for c in [80, 50, 76])
SNQLNM = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
SOKPHU = 304
SOOQNR = "".join(chr(c) for c in [80, 51])
SPFTSI = "".join(
    chr(c)
    for c in [
        83,
        105,
        108,
        101,
        110,
        116,
        77,
        111,
        100,
        101,
        65,
        99,
        116,
        105,
        118,
        101,
    ]
)
SRURAZ = "".join(chr(c) for c in [67, 70, 71, 50, 57])
SSRURA = 476
SSUHBV = 291
STSEMC = "".join(chr(c) for c in [67, 70, 71, 49, 51])
SUHBVW = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
SXUJUT = 364
TACCPQ = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
TATDZX = "".join(chr(c) for c in [67, 70, 71, 52])
TBJEUT = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
TDZXNQ = "".join(chr(c) for c in [67, 70, 71, 53])
TFMNHT = "".join(chr(c) for c in [75, 56])
THBSKS = "".join(chr(c) for c in [85, 100, 65, 117, 120])
THECVY = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
TIDUBS = "".join(chr(c) for c in [50, 53, 65])
TIXQVX = "".join(chr(c) for c in [67, 70, 71, 49, 55])
TMFZDG = "".join(chr(c) for c in [67, 70, 71, 56])
TOPHUG = 358
TSEMCG = 461
TSIFJB = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
TTIDUB = "".join(
    chr(c) for c in [80, 97, 99, 107, 70, 117, 115, 101, 49, 82, 97, 116, 105, 110, 103]
)
TYEKCW = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
TYIYWS = 320
UBSSUH = 7
UBYGDS = 296
UGTYIY = 361
UHBVWV = 293
UIKFWR = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
UJUTYE = 365
UNBLKX = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
UNRJZT = 449
UNXNKM = 321
UOJRJH = "".join(chr(c) for c in [85, 100, 65, 117, 120, 84, 105, 109, 101])
UQEXLS = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
URAZMK = "".join(chr(c) for c in [67, 70, 71, 51, 48])
USOOQN = "".join(chr(c) for c in [80, 50])
USPBWJ = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
UTOPHU = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
UTYEKC = 367
UXFEFJ = 264
UYNQJY = 273
VDNQGV = "".join(chr(c) for c in [80, 52, 76])
VDQLAI = 290
VDSSRU = 475
VHFTHE = 6
VKZILX = "".join(chr(c) for c in [105, 110, 88, 77])
VLASSA = "".join(chr(c) for c in [68, 82, 65, 73, 78])
VOACMC = 472
VUBYGD = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
VUNXNK = "".join(chr(c) for c in [83, 79, 117, 116, 50])
VWVUBY = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
VXOIHB = "".join(chr(c) for c in [67, 70, 71, 49, 57])
VYFCRT = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
VYYPIP = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
WAJVDQ = "".join(chr(c) for c in [105, 110, 89, 74])
WAONPY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
WBSIRY = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
WDAFIK = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
WIVDNQ = "".join(chr(c) for c in [80, 51, 76])
WJYKLG = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
WMNZMJ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
WRKINE = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
WSKWIV = "".join(chr(c) for c in [80, 50, 72])
WVUBYG = 295
XBQFYL = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
XCHWDA = 331
XEKVKZ = "".join(chr(c) for c in [77, 73, 65])
XFEFJT = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
XIBHZV = "".join(chr(c) for c in [67, 70, 71, 50, 50])
XNKMLO = 322
XNQTMF = 454
XOIHBX = 467
XPICXQ = "".join(chr(c) for c in [72, 73])
XQGLRA = 258
XQIEFX = "".join(chr(c) for c in [85, 100, 80, 50])
XQVXOI = "".join(chr(c) for c in [67, 70, 71, 49, 56])
XSJWMN = "".join(chr(c) for c in [77, 69, 68])
XTIACQ = "".join(chr(c) for c in [80, 50, 50])
XUJUTY = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 101, 101, 100]
)
XWAJVD = "".join(chr(c) for c in [75, 56, 48, 48])
XYBQSN = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
YBQSNQ = 285
YEKCWA = 262
YFCRTF = 357
YGDSBD = 297
YIYWSK = "".join(chr(c) for c in [78, 65])
YKLGQP = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
YLIUXF = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
YLJUIK = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
YMOUNB = "".join(chr(c) for c in [67, 80, 79, 84])
YNQJYM = "".join(chr(c) for c in [80, 117, 114, 103, 101])
YOUSPB = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
YPIPIV = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
YWSKWI = "".join(chr(c) for c in [80, 49, 76])
YXBQFY = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
YYLIUX = "".join(chr(c) for c in [78, 69, 87])
YYPIPI = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = 457
ZILXWA = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
ZMJIGY = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
ZMKQTD = 479
ZTATDZ = 451
ZUQEXL = 310
ZVOACM = "".join(chr(c) for c in [67, 70, 71, 50, 52])
ZXNQTM = "".join(chr(c) for c in [67, 70, 71, 54])
AFIKJP = [
    YIYWSK,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    SJMCBF,
]
AJVDQL = [
    NMHXEK,
    MHXEKV,
    HXEKVK,
    XEKVKZ,
    EKVKZI,
    KVKZIL,
    VKZILX,
    KZILXW,
    ZILXWA,
    ILXWAJ,
    LXWAJV,
    XWAJVD,
    WAJVDQ,
]
CWAONP = [EKCWAO, KCWAON]
DUBSSU = [TIDUBS, IDUBSS]
EUTOPH = [
    FCRTFM,
    CRTFMN,
    RTFMNH,
    TFMNHT,
    FMNHTB,
    MNHTBJ,
    NHTBJE,
    HTBJEU,
    XWAJVD,
    HECVYY,
    HECVYY,
    HECVYY,
    TBJEUT,
    BJEUTO,
    JEUTOP,
]
FWRKIN = [HECVYY, KFWRKI, KFWRKI, KFWRKI]
GVUNXN = [
    YIYWSK,
    IYWSKW,
    YWSKWI,
    WSKWIV,
    SKWIVD,
    KWIVDN,
    WIVDNQ,
    IVDNQG,
    VDNQGV,
    OQNRSJ,
    DNQGVU,
    SJMCBF,
    JMCBFE,
    CBFEGZ,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    NQGVUN,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    QGVUNX,
]
IBXTIA = [DNIBXT, NIBXTI]
IIDNIB = [DQLAII, QLAIID, LAIIDN, AIIDNI]
IUSOOQ = [ASSAKQ, JHIUSO, HIUSOO]
JVYFCR = [JJJVYF, JJVYFC]
JWMNZM = [KXSJWM, QXPICX, XSJWMN, XPICXQ, SJWMNZ]
LIUXFE = [ONPYYL, NPYYLI, PYYLIU, YYLIUX, YLIUXF]
MKQTDK = []
NRSJMC = [ASSAKQ, JHIUSO]
PICXQI = [ASSAKQ, QXPICX, XPICXQ]
PIPIVL = [
    THECVY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    HECVYY,
    YPIPIV,
]
QFFTTI = [ACQFFT, CQFFTT]
QGLRAH = [ASSAKQ, XPICXQ]
QTDKHT = [
    JRJHIU,
    USOOQN,
    SOOQNR,
    OOQNRS,
    OQNRSJ,
    RSJMCB,
    SJMCBF,
    JMCBFE,
    CBFEGZ,
    BFEGZU,
    EGZUQE,
    GZUQEX,
    LSXUJU,
    XUJUTY,
    JUTYEK,
    KQTDKH,
]
RAHEOC = [ASSAKQ, LRAHEO]
SPBWJY = [HECVYY, USPBWJ, USPBWJ, USPBWJ]
SSAKQX = [IVLASS, VLASSA, LASSAK, ASSAKQ]
TDKHTZ = [
    AKQXPI,
    XQIEFX,
    IEFXQG,
    EFXQGL,
    FXQGLR,
    GLRAHE,
    HEOCTH,
    OCTHBS,
    THBSKS,
    BSKSOK,
    KSOKPH,
    OKPHUO,
    PHUOJR,
    UOJRJH,
]
TIACQF = [RSJMCB, XTIACQ]
UGSELH = [
    YIYWSK,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    JUGSEL,
]
XLSXUJ = [UQEXLS, QEXLSX, EXLSXU]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return DKHTZB

    @property
    def begin(self):
        return KHTZBB

    @property
    def end(self):
        return HTZBBE

    @property
    def all_device_keys(self):
        return QTDKHT

    @property
    def user_demand_keys(self):
        return TDKHTZ

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoBoolStructAccessor(self.struct, MJVHFT, JVHFTH, VHFTHE, None),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, PIPIVL, None, None, None
            ),
            IPIVLA: GeckoEnumStructAccessor(
                self.struct, IPIVLA, PIVLAS, None, SSAKQX, None, None, SAKQXP
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, ICXQIE, PICXQI, None, CXQIEF, SAKQXP
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, KQXPIC, QIEFXQ, PICXQI, None, CXQIEF, SAKQXP
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, KQXPIC, CXQIEF, PICXQI, None, CXQIEF, SAKQXP
            ),
            EFXQGL: GeckoEnumStructAccessor(
                self.struct, EFXQGL, KQXPIC, VHFTHE, PICXQI, None, CXQIEF, SAKQXP
            ),
            FXQGLR: GeckoEnumStructAccessor(
                self.struct, FXQGLR, XQGLRA, ICXQIE, QGLRAH, None, QIEFXQ, SAKQXP
            ),
            GLRAHE: GeckoEnumStructAccessor(
                self.struct, GLRAHE, XQGLRA, AHEOCT, RAHEOC, None, QIEFXQ, SAKQXP
            ),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, None, RAHEOC, None, None, SAKQXP
            ),
            OCTHBS: GeckoEnumStructAccessor(
                self.struct, OCTHBS, CTHBSK, None, QGLRAH, None, None, SAKQXP
            ),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, None, RAHEOC, None, None, SAKQXP
            ),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, SAKQXP),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, SAKQXP),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, SAKQXP),
            PHUOJR: GeckoByteStructAccessor(self.struct, PHUOJR, HUOJRJ, SAKQXP),
            UOJRJH: GeckoByteStructAccessor(self.struct, UOJRJH, OJRJHI, SAKQXP),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, RJHIUS, ICXQIE, IUSOOQ, None, CXQIEF, None
            ),
            USOOQN: GeckoEnumStructAccessor(
                self.struct, USOOQN, RJHIUS, QIEFXQ, IUSOOQ, None, CXQIEF, None
            ),
            SOOQNR: GeckoEnumStructAccessor(
                self.struct, SOOQNR, RJHIUS, CXQIEF, IUSOOQ, None, CXQIEF, None
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, RJHIUS, VHFTHE, IUSOOQ, None, CXQIEF, None
            ),
            OQNRSJ: GeckoEnumStructAccessor(
                self.struct, OQNRSJ, QNRSJM, ICXQIE, NRSJMC, None, QIEFXQ, None
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, QNRSJM, AHEOCT, RAHEOC, None, QIEFXQ, None
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, QNRSJM, QIEFXQ, RAHEOC, None, QIEFXQ, None
            ),
            JMCBFE: GeckoEnumStructAccessor(
                self.struct, JMCBFE, QNRSJM, MCBFEG, RAHEOC, None, QIEFXQ, None
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, QNRSJM, CXQIEF, RAHEOC, None, QIEFXQ, None
            ),
            BFEGZU: GeckoEnumStructAccessor(
                self.struct, BFEGZU, QNRSJM, FEGZUQ, RAHEOC, None, QIEFXQ, None
            ),
            EGZUQE: GeckoEnumStructAccessor(
                self.struct, EGZUQE, QNRSJM, VHFTHE, RAHEOC, None, QIEFXQ, None
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, ZUQEXL, None, XLSXUJ, None, None, SAKQXP
            ),
            LSXUJU: GeckoEnumStructAccessor(
                self.struct, LSXUJU, SXUJUT, None, XLSXUJ, None, None, None
            ),
            XUJUTY: GeckoWordStructAccessor(self.struct, XUJUTY, UJUTYE, None),
            JUTYEK: GeckoWordStructAccessor(self.struct, JUTYEK, UTYEKC, SAKQXP),
            TYEKCW: GeckoEnumStructAccessor(
                self.struct, TYEKCW, YEKCWA, ICXQIE, CWAONP, None, QIEFXQ, SAKQXP
            ),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, None, LIUXFE, None, None, SAKQXP
            ),
            IUXFEF: GeckoTimeStructAccessor(self.struct, IUXFEF, UXFEFJ, SAKQXP),
            XFEFJT: GeckoByteStructAccessor(self.struct, XFEFJT, FEFJTA, SAKQXP),
            EFJTAC: GeckoEnumStructAccessor(
                self.struct, EFJTAC, YEKCWA, QIEFXQ, CWAONP, None, QIEFXQ, SAKQXP
            ),
            FJTACC: GeckoEnumStructAccessor(
                self.struct, FJTACC, JTACCP, None, LIUXFE, None, None, SAKQXP
            ),
            TACCPQ: GeckoTimeStructAccessor(self.struct, TACCPQ, ACCPQI, SAKQXP),
            CCPQIP: GeckoByteStructAccessor(self.struct, CCPQIP, CPQIPO, SAKQXP),
            PQIPOU: GeckoByteStructAccessor(self.struct, PQIPOU, QIPOUY, SAKQXP),
            IPOUYN: GeckoByteStructAccessor(self.struct, IPOUYN, POUYNQ, SAKQXP),
            OUYNQJ: GeckoBoolStructAccessor(self.struct, OUYNQJ, UYNQJY, ICXQIE, None),
            YNQJYM: GeckoBoolStructAccessor(self.struct, YNQJYM, UYNQJY, QIEFXQ, None),
            NQJYMO: GeckoBoolStructAccessor(self.struct, NQJYMO, UYNQJY, MCBFEG, None),
            QJYMOU: GeckoBoolStructAccessor(self.struct, QJYMOU, UYNQJY, CXQIEF, None),
            JYMOUN: GeckoBoolStructAccessor(self.struct, JYMOUN, UYNQJY, FEGZUQ, None),
            YMOUNB: GeckoBoolStructAccessor(self.struct, YMOUNB, JVHFTH, QIEFXQ, None),
            MOUNBL: GeckoBoolStructAccessor(self.struct, MOUNBL, OUNBLK, MCBFEG, None),
            UNBLKX: GeckoBoolStructAccessor(self.struct, UNBLKX, OUNBLK, FEGZUQ, None),
            NBLKXS: GeckoBoolStructAccessor(self.struct, NBLKXS, OUNBLK, VHFTHE, None),
            BLKXSJ: GeckoEnumStructAccessor(
                self.struct, BLKXSJ, LKXSJW, None, JWMNZM, None, None, None
            ),
            WMNZMJ: GeckoBoolStructAccessor(self.struct, WMNZMJ, MNZMJI, FEGZUQ, None),
            NZMJIG: GeckoBoolStructAccessor(self.struct, NZMJIG, MNZMJI, VHFTHE, None),
            ZMJIGY: GeckoWordStructAccessor(self.struct, ZMJIGY, MJIGYO, None),
            JIGYOU: GeckoBoolStructAccessor(self.struct, JIGYOU, JVHFTH, AHEOCT, None),
            IGYOUS: GeckoTempStructAccessor(self.struct, IGYOUS, GYOUSP, None),
            YOUSPB: GeckoTempStructAccessor(self.struct, YOUSPB, OUSPBW, None),
            USPBWJ: GeckoEnumStructAccessor(
                self.struct, USPBWJ, QNRSJM, FEGZUQ, SPBWJY, None, CXQIEF, None
            ),
            PBWJYK: GeckoBoolStructAccessor(self.struct, PBWJYK, BWJYKL, QIEFXQ, None),
            WJYKLG: GeckoBoolStructAccessor(self.struct, WJYKLG, JYKLGQ, QIEFXQ, None),
            YKLGQP: GeckoBoolStructAccessor(self.struct, YKLGQP, KLGQPL, AHEOCT, None),
            LGQPLS: GeckoBoolStructAccessor(
                self.struct, LGQPLS, KLGQPL, QIEFXQ, SAKQXP
            ),
            GQPLSP: GeckoBoolStructAccessor(self.struct, GQPLSP, QPLSPF, AHEOCT, None),
            PLSPFT: GeckoByteStructAccessor(self.struct, PLSPFT, LSPFTS, None),
            SPFTSI: GeckoBoolStructAccessor(self.struct, SPFTSI, PFTSIF, ICXQIE, None),
            FTSIFJ: GeckoBoolStructAccessor(self.struct, FTSIFJ, JVHFTH, MCBFEG, None),
            TSIFJB: GeckoBoolStructAccessor(self.struct, TSIFJB, OUNBLK, ICXQIE, None),
            SIFJBI: GeckoBoolStructAccessor(self.struct, SIFJBI, OUNBLK, AHEOCT, None),
            IFJBIA: GeckoBoolStructAccessor(self.struct, IFJBIA, FJBIAM, QIEFXQ, None),
            JBIAMJ: GeckoBoolStructAccessor(self.struct, JBIAMJ, FJBIAM, MCBFEG, None),
            BIAMJM: GeckoBoolStructAccessor(self.struct, BIAMJM, IAMJMA, MCBFEG, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, IAMJMA, CXQIEF, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, IAMJMA, FEGZUQ, None),
            JMAOAW: GeckoBoolStructAccessor(self.struct, JMAOAW, IAMJMA, VHFTHE, None),
            MAOAWB: GeckoBoolStructAccessor(self.struct, MAOAWB, AOAWBS, MCBFEG, None),
            OAWBSI: GeckoBoolStructAccessor(self.struct, OAWBSI, AOAWBS, CXQIEF, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, AOAWBS, FEGZUQ, None),
            WBSIRY: GeckoBoolStructAccessor(self.struct, WBSIRY, AOAWBS, VHFTHE, None),
            BSIRYX: GeckoBoolStructAccessor(self.struct, BSIRYX, SIRYXB, QIEFXQ, None),
            IRYXBQ: GeckoBoolStructAccessor(self.struct, IRYXBQ, SIRYXB, MCBFEG, None),
            RYXBQF: GeckoBoolStructAccessor(self.struct, RYXBQF, QPLSPF, MCBFEG, None),
            YXBQFY: GeckoBoolStructAccessor(self.struct, YXBQFY, MNZMJI, ICXQIE, None),
            XBQFYL: GeckoBoolStructAccessor(self.struct, XBQFYL, MNZMJI, AHEOCT, None),
            BQFYLJ: GeckoBoolStructAccessor(self.struct, BQFYLJ, QFYLJU, ICXQIE, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, JYKLGQ, ICXQIE, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, FJBIAM, ICXQIE, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, FJBIAM, AHEOCT, None),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, FJBIAM, CXQIEF, None),
            UIKFWR: GeckoBoolStructAccessor(self.struct, UIKFWR, IKFWRK, ICXQIE, None),
            KFWRKI: GeckoEnumStructAccessor(
                self.struct, KFWRKI, IKFWRK, AHEOCT, FWRKIN, None, CXQIEF, None
            ),
            WRKINE: GeckoWordStructAccessor(self.struct, WRKINE, RKINEJ, None),
            KINEJN: GeckoBoolStructAccessor(self.struct, KINEJN, INEJNI, ICXQIE, None),
            NEJNIB: GeckoBoolStructAccessor(self.struct, NEJNIB, EJNIBX, ICXQIE, None),
            JNIBXY: GeckoBoolStructAccessor(self.struct, JNIBXY, EJNIBX, AHEOCT, None),
            NIBXYB: GeckoBoolStructAccessor(self.struct, NIBXYB, SIRYXB, ICXQIE, None),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, SIRYXB, AHEOCT, None),
            BXYBQS: GeckoBoolStructAccessor(self.struct, BXYBQS, SIRYXB, CXQIEF, None),
            XYBQSN: GeckoWordStructAccessor(self.struct, XYBQSN, YBQSNQ, None),
            BQSNQL: GeckoByteStructAccessor(self.struct, BQSNQL, QSNQLN, None),
            SNQLNM: GeckoByteStructAccessor(self.struct, SNQLNM, NQLNMH, None),
            QLNMHX: GeckoEnumStructAccessor(
                self.struct, QLNMHX, LNMHXE, None, AJVDQL, None, None, None
            ),
            JVDQLA: GeckoEnumStructAccessor(
                self.struct, JVDQLA, VDQLAI, ICXQIE, IIDNIB, None, CXQIEF, None
            ),
            IDNIBX: GeckoEnumStructAccessor(
                self.struct, IDNIBX, VDQLAI, QIEFXQ, IBXTIA, None, QIEFXQ, None
            ),
            BXTIAC: GeckoEnumStructAccessor(
                self.struct, BXTIAC, VDQLAI, MCBFEG, TIACQF, None, QIEFXQ, None
            ),
            IACQFF: GeckoEnumStructAccessor(
                self.struct, IACQFF, VDQLAI, CXQIEF, QFFTTI, None, QIEFXQ, None
            ),
            FFTTID: GeckoBoolStructAccessor(self.struct, FFTTID, VDQLAI, FEGZUQ, None),
            FTTIDU: GeckoBoolStructAccessor(self.struct, FTTIDU, VDQLAI, VHFTHE, None),
            TTIDUB: GeckoEnumStructAccessor(
                self.struct, TTIDUB, VDQLAI, UBSSUH, DUBSSU, None, QIEFXQ, None
            ),
            BSSUHB: GeckoWordStructAccessor(self.struct, BSSUHB, SSUHBV, None),
            SUHBVW: GeckoByteStructAccessor(self.struct, SUHBVW, UHBVWV, None),
            HBVWVU: GeckoByteStructAccessor(self.struct, HBVWVU, BVWVUB, None),
            VWVUBY: GeckoByteStructAccessor(self.struct, VWVUBY, WVUBYG, None),
            VUBYGD: GeckoByteStructAccessor(self.struct, VUBYGD, UBYGDS, None),
            BYGDSB: GeckoWordStructAccessor(self.struct, BYGDSB, YGDSBD, None),
            GDSBDJ: GeckoByteStructAccessor(self.struct, GDSBDJ, DSBDJQ, None),
            SBDJQR: GeckoByteStructAccessor(self.struct, SBDJQR, BDJQRJ, None),
            DJQRJJ: GeckoWordStructAccessor(self.struct, DJQRJJ, JQRJJJ, None),
            QRJJJV: GeckoEnumStructAccessor(
                self.struct, QRJJJV, RJJJVY, None, JVYFCR, None, QIEFXQ, SAKQXP
            ),
            VYFCRT: GeckoEnumStructAccessor(
                self.struct, VYFCRT, YFCRTF, None, EUTOPH, None, None, None
            ),
            UTOPHU: GeckoWordStructAccessor(self.struct, UTOPHU, TOPHUG, None),
            OPHUGT: GeckoByteStructAccessor(self.struct, OPHUGT, PHUGTY, None),
            HUGTYI: GeckoByteStructAccessor(self.struct, HUGTYI, UGTYIY, None),
            GTYIYW: GeckoEnumStructAccessor(
                self.struct, GTYIYW, TYIYWS, None, GVUNXN, None, None, SAKQXP
            ),
            VUNXNK: GeckoEnumStructAccessor(
                self.struct, VUNXNK, UNXNKM, None, GVUNXN, None, None, SAKQXP
            ),
            NXNKML: GeckoEnumStructAccessor(
                self.struct, NXNKML, XNKMLO, None, GVUNXN, None, None, SAKQXP
            ),
            NKMLOI: GeckoEnumStructAccessor(
                self.struct, NKMLOI, KMLOIJ, None, GVUNXN, None, None, SAKQXP
            ),
            MLOIJU: GeckoEnumStructAccessor(
                self.struct, MLOIJU, LOIJUG, None, GVUNXN, None, None, SAKQXP
            ),
            OIJUGS: GeckoEnumStructAccessor(
                self.struct, OIJUGS, IJUGSE, None, UGSELH, None, None, SAKQXP
            ),
            GSELHB: GeckoByteStructAccessor(self.struct, GSELHB, SELHBQ, SAKQXP),
            ELHBQN: GeckoByteStructAccessor(self.struct, ELHBQN, LHBQNR, SAKQXP),
            HBQNRX: GeckoByteStructAccessor(self.struct, HBQNRX, BQNRXC, SAKQXP),
            QNRXCH: GeckoByteStructAccessor(self.struct, QNRXCH, NRXCHW, SAKQXP),
            RXCHWD: GeckoByteStructAccessor(self.struct, RXCHWD, XCHWDA, SAKQXP),
            CHWDAF: GeckoByteStructAccessor(self.struct, CHWDAF, HWDAFI, SAKQXP),
            WDAFIK: GeckoEnumStructAccessor(
                self.struct, WDAFIK, DAFIKJ, None, AFIKJP, None, None, SAKQXP
            ),
            FIKJPU: GeckoByteStructAccessor(self.struct, FIKJPU, IKJPUN, SAKQXP),
        }
